@@ -5,7 +5,7 @@
 #  source, and has the attribution requirements (GPL Section 7) at
 #  https://statnet.org/attribution .
 #
-#  Copyright 2015-2025 Statnet Commons
+#  Copyright 2015-2026 Statnet Commons
 ################################################################################
 
 
@@ -70,16 +70,13 @@
 #' @author Pavel N. Krivitsky
 #' @references
 #' 
-#' 
-#' Pavel N. Krivitsky and Martina Morris (2017). "Inference for social network models from egocentrically sampled data, with application to understanding persistent racial disparities in HIV prevalence in the US." *Annals of Applied Statistics*, 11(1): 427–455. \doi{10.1214/16-AOAS1010}
+#' \insertRef{KrMo2017}{ergm.ego}
 #'
-#' Pavel N. Krivitsky, Martina Morris, and Michał Bojanowski (2019). "Inference for Exponential-Family Random Graph Models from Egocentrically-Sampled Data with Alter–Alter Relations." NIASRA Working Paper 08-19. \url{https://www.uow.edu.au/niasra/publications/}
+#' \insertRef{KrMoBo2019}{ergm.ego}
 #'
-#' Pavel N. Krivitsky, Michał Bojanowski, and Martina Morris (2020). "Impact of survey design on estimation of exponential-family random graph models from egocentrically-sampled data." *Social Networks*, to appear. \doi{10.1016/j.socnet.2020.10.001}
+#' \insertRef{KrBoMo2020}{ergm.ego}
 #' 
-#' Pavel N. Krivitsky, Mark S. Handcock, and Martina Morris (2011). "Adjusting for
-#' Network Size and Composition Effects in Exponential-Family Random Graph
-#' Models." \emph{Statistical Methodology}, 8(4): 319–339. \doi{10.1016/j.stamet.2011.01.005}
+#' \insertRef{KrHaMo2011}{ergm.ego}
 #'
 #' @keywords models
 #' @seealso [ergm()]
@@ -279,8 +276,6 @@ ergm.ego <- function(formula, popsize=1, offset.coef=NULL, constraints=~.,..., b
     
     vcov <- matrix(NA, length(coef), length(coef))
 
-    iDtDe <- solve(DtDe[!novar,!novar,drop=FALSE])
-
     # Augment the statistics covariance matrix with 0 rows and columns
     # for offsets, then pre- and post-multiply it by the derivative of
     # theta with to eta.
@@ -289,7 +284,9 @@ ergm.ego <- function(formula, popsize=1, offset.coef=NULL, constraints=~.,..., b
     vaug[!ergm.fit$etamap$offsetmap, !ergm.fit$etamap$offsetmap] <- v[!vdropped,!vdropped]
     vaug <- ergm.etagradmult(coef, t(ergm.etagradmult(coef, vaug, ergm.fit$etamap)), ergm.fit$etamap)
     
-    vcov[!oi,!oi] <- iDtDe%*%vaug[!oi,!oi,drop=FALSE]%*%iDtDe
+    vcov[!oi, !oi] <- sandwich_sginv(DtDe[!novar, !novar, drop = FALSE],
+                                     vaug[!oi, !oi, drop = FALSE],
+                                     tol = .Machine$double.eps^(3 / 4))
 
     rownames(vcov) <- colnames(vcov) <- names(coef)
 
