@@ -5,7 +5,7 @@
 #  source, and has the attribution requirements (GPL Section 7) at
 #  https://statnet.org/attribution .
 #
-#  Copyright 2015-2025 Statnet Commons
+#  Copyright 2015-2026 Statnet Commons
 ################################################################################
 
 test_that("it just works for model without offsets", {
@@ -17,9 +17,7 @@ test_that("it just works for model without offsets", {
     popsize=network.size(faux.mesa.high),
     control=snctrl(MCMLE.maxit=2)
   )
-  expect_silent(
-    p <- predict(egofit)
-  )
+  expect_warning(p <- predict(egofit), NA)
   expect_true(all(is.finite(p$p)))
 })
 
@@ -37,8 +35,6 @@ test_that("it just works for model with offsets", {
     offset.coef = rep(-Inf, 2),
     control=snctrl(MCMLE.maxit=2)
   )
-  expect_silent(
-    p <- predict(fit) # data frame
-  )
+  expect_warning(p <- predict(fit), NA) # data frame
   expect_true(all(is.finite(p$p)))
 })
